# Slot: subclass_of


instances of this class are considered/required to be sub classes of the target URI

URI: [http://w3id.org/biolink/biolinkml/meta/subclass_of](slot_uri)
## Domain and Range

[ClassDefinition](ClassDefinition.md) -><sub>opt</sub> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
